==> edge-login-ui-rn-0.10.11.tgz: package/lib/components/scenes/ChangePasswordScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Keyboard, KeyboardAvoidingView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { validateConfirmPassword, validatePassword } from '../../actions/CreateAccountActions';
import { onComplete } from '../../actions/WorkflowActions';
import s from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler.js';
import { useDispatch, useSelector } from '../../types/ReduxTypes';
import { logEvent } from '../../util/analytics';
import { ButtonsModal } from '../modals/ButtonsModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
import { Fade } from '../themed/Fade';
import { FormError } from '../themed/FormError';
import { MainButton } from '../themed/MainButton';
import { OutlinedTextInput } from '../themed/OutlinedTextInput';
import { PasswordStatus } from '../themed/PasswordStatus';
import { ThemedScene } from '../themed/ThemedScene';
const ChangePasswordSceneComponent = ({ title, onBack, onSkip, onSubmit, mainButtonLabel = s.strings.done }) => {
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const [focusFirst, setFocusFirst] = React.useState(true);
    const [focusSecond, setFocusSecond] = React.useState(false);
    const [hidePassword, setHidePassword] = React.useState(true);
    const [spinning, setSpinning] = React.useState(false);
    const hasPasswordStatus = useSelector(state => state.passwordStatus != null);
    const passed = useSelector(state => { var _a, _b; return (_b = (_a = state === null || state === void 0 ? void 0 : state.passwordStatus) === null || _a === void 0 ? void 0 : _a.passed) !== null && _b !== void 0 ? _b : false; });
    const password = useSelector(state => { var _a; return (_a = state.create.password) !== null && _a !== void 0 ? _a : ''; });
    const confirmPassword = useSelector(state => { var _a; return (_a = state.create.confirmPassword) !== null && _a !== void 0 ? _a : ''; });
    const confirmError = useSelector(state => { var _a; return (_a = state.create.confirmPasswordErrorMessage) !== null && _a !== void 0 ? _a : ''; });
    const createError = useSelector(state => { var _a; return (_a = state.create.createPasswordErrorMessage) !== null && _a !== void 0 ? _a : ''; });
    const hasError = confirmError !== '' || createError !== '';
    const isValidPassword = passed && password === confirmPassword && !hasError;
    const handleHidePassword = useHandler(() => {
        setHidePassword(!hidePassword);
    });
    const handlePress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (!isValidPassword)
            return;
        setSpinning(true);
        try {
            yield onSubmit(password);
        }
        catch (e) {
            showError(e);
            setSpinning(false);
        }
    }));
    const handleFocusSwitch = () => {
        setFocusFirst(false);
        setFocusSecond(true);
    };
    const validatePasswordDispatch = (password) => {
        dispatch(validatePassword(password));
    };
    const validateConfirmPasswordDispatch = (password) => {
        dispatch(validateConfirmPassword(password));
    };
    const renderInterior = () => {
        return (React.createElement(React.Fragment, null,
            hasPasswordStatus ? (React.createElement(PasswordStatus, { marginRem: [0.5, 0.5, 1.25] })) : (React.createElement(EdgeText, { style: styles.description, numberOfLines: 4 }, s.strings.password_desc)),
            React.createElement(OutlinedTextInput, { value: password, secureTextEntry: true, returnKeyType: "next", label: s.strings.password, autoFocus: focusFirst, hidePassword: hidePassword, onChangeText: validatePasswordDispatch, onSubmitEditing: handleFocusSwitch, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(OutlinedTextInput, { value: confirmPassword, secureTextEntry: true, returnKeyType: "go", label: s.strings.confirm_password, autoFocus: focusSecond, hidePassword: hidePassword, onChangeText: validateConfirmPasswordDispatch, onSubmitEditing: handlePress, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(FormError, { marginRem: [0, 0.75], invisible: !hasError }, confirmError !== '' ? confirmError : createError),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: isValidPassword, hidden: true }, spinning ? (React.createElement(MainButton, { alignSelf: "center", disabled: true, marginRem: 0.5, type: "secondary", spinner: true })) : (React.createElement(MainButton, { alignSelf: "center", label: mainButtonLabel, marginRem: 0.5, onPress: handlePress, type: "secondary" }))))));
    };
    return (React.createElement(ThemedScene, { onBack: onBack, onSkip: onSkip, title: title }, focusSecond ? (React.createElement(KeyboardAvoidingView, { style: styles.container, behavior: "position", keyboardVerticalOffset: -150 }, renderInterior())) : (React.createElement(View, { style: styles.container }, renderInterior()))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        overflow: 'hidden'
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25),
        marginTop: theme.rem(1.5)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(1)
    }
}));
// The scene for existing users to change their password
export const ChangePasswordScene = () => {
    const dispatch = useDispatch();
    const account = useSelector(state => { var _a; return (_a = state.account) !== null && _a !== void 0 ? _a : undefined; });
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        if (account == null)
            return;
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })));
        dispatch(onComplete());
    }));
    return React.createElement(ChangePasswordSceneComponent, { onSubmit: handleSubmit });
};
// The scene for existing users to recover their password
export const ResecurePasswordScene = () => {
    const dispatch = useDispatch();
    const account = useSelector(state => { var _a; return (_a = state.account) !== null && _a !== void 0 ? _a : undefined; });
    const handleSkip = useHandler(() => {
        dispatch({ type: 'RESECURE_PIN' });
    });
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        if (account == null)
            return;
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })));
        dispatch({ type: 'RESECURE_PIN' });
    }));
    return (React.createElement(ChangePasswordSceneComponent, { onSkip: handleSkip, title: s.strings.change_password, onSubmit: handleSubmit }));
};
// The scene for new users to create a password
export const NewAccountPasswordScene = () => {
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({ type: 'NEW_ACCOUNT_USERNAME' });
    });
    const handleSubmit = useHandler(() => {
        logEvent('Signup_Password_Valid');
        dispatch({ type: 'NEW_ACCOUNT_PIN' });
    });
    return (React.createElement(ChangePasswordSceneComponent, { onBack: handleBack, onSubmit: handleSubmit, title: s.strings.choose_title_password, mainButtonLabel: s.strings.next_label }));
};

==> edge-login-ui-rn-0.10.14.tgz: package/lib/components/scenes/ChangePasswordScene.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import * as React from 'react';
import { Keyboard, KeyboardAvoidingView, View } from 'react-native';
import { cacheStyles } from 'react-native-patina';
import { validateConfirmPassword, validatePassword } from '../../actions/CreateAccountActions';
import { onComplete } from '../../actions/WorkflowActions';
import s from '../../common/locales/strings';
import { useHandler } from '../../hooks/useHandler.js';
import { useDispatch, useSelector } from '../../types/ReduxTypes';
import { logEvent } from '../../util/analytics';
import { ButtonsModal } from '../modals/ButtonsModal';
import { Airship, showError } from '../services/AirshipInstance';
import { useTheme } from '../services/ThemeContext';
import { EdgeText } from '../themed/EdgeText';
import { Fade } from '../themed/Fade';
import { FormError } from '../themed/FormError';
import { MainButton } from '../themed/MainButton';
import { OutlinedTextInput } from '../themed/OutlinedTextInput';
import { PasswordStatus } from '../themed/PasswordStatus';
import { ThemedScene } from '../themed/ThemedScene';
const ChangePasswordSceneComponent = ({ title, onBack, onSkip, onSubmit, mainButtonLabel = s.strings.done }) => {
    const theme = useTheme();
    const styles = getStyles(theme);
    const dispatch = useDispatch();
    const [focusFirst, setFocusFirst] = React.useState(true);
    const [focusSecond, setFocusSecond] = React.useState(false);
    const [hidePassword, setHidePassword] = React.useState(true);
    const [spinning, setSpinning] = React.useState(false);
    const [isShowError, setIsShowError] = React.useState(false);
    const hasPasswordStatus = useSelector(state => state.passwordStatus != null);
    const isRequirementsMet = useSelector(state => { var _a, _b; return (_b = (_a = state.passwordStatus) === null || _a === void 0 ? void 0 : _a.passed) !== null && _b !== void 0 ? _b : false; });
    const password = useSelector(state => { var _a; return (_a = state.create.password) !== null && _a !== void 0 ? _a : ''; });
    const confirmPassword = useSelector(state => { var _a; return (_a = state.create.confirmPassword) !== null && _a !== void 0 ? _a : ''; });
    const confirmPasswordErrorMessage = useSelector(state => { var _a; return (_a = state.create.confirmPasswordErrorMessage) !== null && _a !== void 0 ? _a : ''; });
    const handleHidePassword = useHandler(() => {
        setHidePassword(!hidePassword);
    });
    const handlePress = useHandler(() => __awaiter(void 0, void 0, void 0, function* () {
        if (password !== confirmPassword) {
            setIsShowError(true);
            return;
        }
        setSpinning(true);
        try {
            yield onSubmit(password);
        }
        catch (e) {
            showError(e);
            setSpinning(false);
        }
    }));
    const handleFocusSwitch = () => {
        setFocusFirst(false);
        setFocusSecond(true);
    };
    const validatePasswordDispatch = (password) => {
        setIsShowError(false);
        dispatch(validatePassword(password));
    };
    const validateConfirmPasswordDispatch = (password) => {
        setIsShowError(false);
        dispatch(validateConfirmPassword(password));
    };
    const renderInterior = () => {
        return (React.createElement(React.Fragment, null,
            hasPasswordStatus ? (React.createElement(PasswordStatus, { marginRem: [0.5, 0.5, 1.25] })) : (React.createElement(EdgeText, { style: styles.description, numberOfLines: 4 }, s.strings.password_desc)),
            React.createElement(OutlinedTextInput, { value: password, secureTextEntry: true, returnKeyType: "next", label: s.strings.password, autoFocus: focusFirst, hidePassword: hidePassword, onChangeText: validatePasswordDispatch, onSubmitEditing: handleFocusSwitch, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(OutlinedTextInput, { value: confirmPassword, secureTextEntry: true, returnKeyType: "go", label: s.strings.confirm_password, autoFocus: focusSecond, hidePassword: hidePassword, onChangeText: validateConfirmPasswordDispatch, onSubmitEditing: handlePress, onHidePassword: handleHidePassword, clearIcon: true, searchIcon: false, marginRem: [0, 0.75, 1.25], maxLength: 100 }),
            React.createElement(FormError, { marginRem: [0, 0.75], invisible: !isShowError }, confirmPasswordErrorMessage),
            React.createElement(View, { style: styles.actions },
                React.createElement(Fade, { visible: !isShowError, hidden: true }, spinning ? (React.createElement(MainButton, { alignSelf: "center", disabled: true, marginRem: 0.5, type: "secondary", spinner: true })) : (React.createElement(MainButton, { alignSelf: "center", label: mainButtonLabel, disabled: !isRequirementsMet || confirmPassword === '', marginRem: 0.5, onPress: handlePress, type: "secondary" }))))));
    };
    return (React.createElement(ThemedScene, { onBack: onBack, onSkip: onSkip, title: title }, focusSecond ? (React.createElement(KeyboardAvoidingView, { style: styles.container, behavior: "position", keyboardVerticalOffset: -150 }, renderInterior())) : (React.createElement(View, { style: styles.container }, renderInterior()))));
};
const getStyles = cacheStyles((theme) => ({
    container: {
        flex: 1,
        marginHorizontal: theme.rem(0.5),
        overflow: 'hidden'
    },
    description: {
        fontFamily: theme.fontFaceDefault,
        fontSize: theme.rem(0.875),
        marginBottom: theme.rem(3.25),
        marginTop: theme.rem(1.5)
    },
    actions: {
        flexDirection: 'row',
        justifyContent: 'center',
        marginTop: theme.rem(1)
    }
}));
// The scene for existing users to change their password
export const ChangePasswordScene = () => {
    const dispatch = useDispatch();
    const account = useSelector(state => { var _a; return (_a = state.account) !== null && _a !== void 0 ? _a : undefined; });
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        if (account == null)
            return;
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })));
        dispatch(onComplete());
    }));
    return React.createElement(ChangePasswordSceneComponent, { onSubmit: handleSubmit });
};
// The scene for existing users to recover their password
export const ResecurePasswordScene = () => {
    const dispatch = useDispatch();
    const account = useSelector(state => { var _a; return (_a = state.account) !== null && _a !== void 0 ? _a : undefined; });
    const handleSkip = useHandler(() => {
        dispatch({ type: 'RESECURE_PIN' });
    });
    const handleSubmit = useHandler((password) => __awaiter(void 0, void 0, void 0, function* () {
        Keyboard.dismiss();
        if (account == null)
            return;
        yield account.changePassword(password);
        yield Airship.show(bridge => (React.createElement(ButtonsModal, { bridge: bridge, title: s.strings.password_changed, message: s.strings.pwd_change_modal, buttons: { ok: { label: s.strings.ok } } })));
        dispatch({ type: 'RESECURE_PIN' });
    }));
    return (React.createElement(ChangePasswordSceneComponent, { onSkip: handleSkip, title: s.strings.change_password, onSubmit: handleSubmit }));
};
// The scene for new users to create a password
export const NewAccountPasswordScene = () => {
    const dispatch = useDispatch();
    const handleBack = useHandler(() => {
        dispatch({ type: 'NEW_ACCOUNT_USERNAME' });
    });
    const handleSubmit = useHandler(() => {
        logEvent('Signup_Password_Valid');
        dispatch({ type: 'NEW_ACCOUNT_PIN' });
    });
    return (React.createElement(ChangePasswordSceneComponent, { onBack: handleBack, onSubmit: handleSubmit, title: s.strings.choose_title_password, mainButtonLabel: s.strings.next_label }));
};
